from py2neo import Graph


def graph_engine(engine, **kwargs):
    if engine == "neo4j":
        return Graph(**kwargs)
    else:
        raise Exception("Sorry, we haven't implemented that engine yet.")





from setuptools import setup

setup(name='grandas',
      version='0.1dev',
      description='Simple and flexible graph database analysis',
      url='http://github.com/austinbrian/grandas',
      author='Brian Austin',
      author_email='austin.brian+gh@gmail.com',
      license='BSD-3',
      long_description=open('README.md').read(),
      packages=['grandas'],
      zip_safe=False)
